@@ -30,9 +30,14 @@ PORTICUS_ALBUM_TEMPLATE_FRAGMENT = 'porticus/templatetags/album_detail_fragment.
 PORTICUS_GALLERIES_TEMPLATE_FRAGMENT = 'porticus/templatetags/gallery_list_fragment.html'
 
 # Ressource file types
+PORTICUS_RESSOURCE_FILETYPES = (
+    (0, 'binary'),
+    (1, 'image'),
+    (2, "youtube"),
+)
 PORTICUS_RESSOURCE_FILETYPE_CHOICES = (
     (0, gettext('Binary')),
     (1, gettext('Image')),
-    (2, gettext('Youtube (only on file url)')),
+    (2, gettext("Youtube (only with 'file_url') usage")),
 )
 PORTICUS_RESSOURCE_FILETYPE_DEFAULT = 1
